Python API
##########

.. highlight: python

:mod:`gpypi` -- Main package 
*****************************

.. automodule:: gpypi

:mod:`gpypi.sdist_ebuild` -- Distutils command
====================================================

.. automodule:: gpypi.sdist_ebuild
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.cli` -- Command line handling
====================================================

.. automodule:: gpypi.cli
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.config` -- Configuration handling
====================================================

.. automodule:: gpypi.config
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.ebuild` -- Ebuild generation module
=========================================================

.. automodule:: gpypi.ebuild
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.enamer` -- Utilities for metadata conversion
=========================================================

.. automodule:: gpypi.enamer
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

:mod:`gpypi.exc` -- :mod:`gpypi` specific Exceptions
=========================================================

.. automodule:: gpypi.exc
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.portage_utils` -- Portage utilities
=========================================================

.. automodule:: gpypi.portage_utils
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:

:mod:`gpypi.workflow` -- Generate manifest, metadata, changelog ...
=====================================================================

.. automodule:: gpypi.workflow
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:


:mod:`gpypi.tests` -- Unittests package
****************************************

.. automodule:: gpypi.tests

:mod:`gpypi.tests.test_sdist_ebuild`
=====================================

.. automodule:: gpypi.tests.test_sdist_ebuild
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.tests.test_cli`
=====================================

.. automodule:: gpypi.tests.test_cli
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.tests.test_config`
=====================================

.. automodule:: gpypi.tests.test_config
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.tests.test_ebuild`
=====================================

.. automodule:: gpypi.tests.test_ebuild
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.tests.test_enamer`
=====================================

.. automodule:: gpypi.tests.test_enamer
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.tests.test_portage_utils`
==========================================

.. automodule:: gpypi.tests.test_portage_utils
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.tests.test_pypi`
=====================================

.. automodule:: gpypi.tests.test_pypi
   :members:
   :undoc-members:
   :show-inheritance:

:mod:`gpypi.tests.test_workflow`
=====================================

.. automodule:: gpypi.tests.test_workflow
   :members:
   :undoc-members:
   :show-inheritance:
